@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -31,16 +31,12 @@ class CTriggerPrototype extends CTriggerGeneral {
 	/**
 	 * Get trigger prototypes from database.
 	 *
-	 * @see https://www.zabbix.com/documentation/3.2/manual/api/reference/triggerprototype/get
-	 *
 	 * @param array $options
 	 *
 	 * @return array|int
 	 */
 	public function get(array $options = []) {
 		$result = [];
-		$userType = self::$userData['type'];
-		$userId = self::$userData['userid'];
 
 		$sqlParts = [
 			'select'	=> ['triggers' => 't.triggerid'],
@@ -66,7 +62,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 			'active' 						=> null,
 			'maintenance'					=> null,
 			'nopermissions'					=> null,
-			'editable'						=> null,
+			'editable'						=> false,
 			// filter
 			'group'							=> null,
 			'host'							=> null,
@@ -74,8 +70,8 @@ class CTriggerPrototype extends CTriggerGeneral {
 			'filter'						=> null,
 			'search'						=> null,
 			'searchByAny'					=> null,
-			'startSearch'					=> null,
-			'excludeSearch'					=> null,
+			'startSearch'					=> false,
+			'excludeSearch'					=> false,
 			'searchWildcardsEnabled'		=> null,
 			// output
 			'expandExpression'				=> null,
@@ -87,9 +83,9 @@ class CTriggerPrototype extends CTriggerGeneral {
 			'selectDependencies'			=> null,
 			'selectDiscoveryRule'			=> null,
 			'selectTags'					=> null,
-			'countOutput'					=> null,
-			'groupCount'					=> null,
-			'preservekeys'					=> null,
+			'countOutput'					=> false,
+			'groupCount'					=> false,
+			'preservekeys'					=> false,
 			'sortfield'						=> '',
 			'sortorder'						=> '',
 			'limit'							=> null,
@@ -98,10 +94,9 @@ class CTriggerPrototype extends CTriggerGeneral {
 		$options = zbx_array_merge($defOptions, $options);
 
 		// editable + permission check
-		if ($userType != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
-
-			$userGroups = getUserGroupsByUserId($userId);
+			$userGroups = getUserGroupsByUserId(self::$userData['userid']);
 
 			$sqlParts['where'][] = 'NOT EXISTS ('.
 				'SELECT NULL'.
@@ -131,7 +126,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 			$sqlParts['where']['fi'] = 'f.itemid=i.itemid';
 			$sqlParts['where']['groupid'] = dbConditionInt('hg.groupid', $options['groupids']);
 
-			if ($options['groupCount'] !== null) {
+			if ($options['groupCount']) {
 				$sqlParts['group']['hg'] = 'hg.groupid';
 			}
 		}
@@ -159,7 +154,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 			$sqlParts['where']['ft'] = 'f.triggerid=t.triggerid';
 			$sqlParts['where']['fi'] = 'f.itemid=i.itemid';
 
-			if ($options['groupCount'] !== null) {
+			if ($options['groupCount']) {
 				$sqlParts['group']['i'] = 'i.hostid';
 			}
 		}
@@ -179,7 +174,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 			$sqlParts['where']['itemid'] = dbConditionInt('f.itemid', $options['itemids']);
 			$sqlParts['where']['ft'] = 'f.triggerid=t.triggerid';
 
-			if ($options['groupCount'] !== null) {
+			if ($options['groupCount']) {
 				$sqlParts['group']['f'] = 'f.itemid';
 			}
 		}
@@ -207,7 +202,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 			$sqlParts['where']['ft'] = 'f.triggerid=t.triggerid';
 			$sqlParts['where'][] = dbConditionInt('id.parent_itemid', $options['discoveryids']);
 
-			if ($options['groupCount'] !== null) {
+			if ($options['groupCount']) {
 				$sqlParts['group']['id'] = 'id.parent_itemid';
 			}
 		}
@@ -218,7 +213,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 
 			$sqlParts['from']['functions'] = 'functions f';
 			$sqlParts['where']['ft'] = 'f.triggerid=t.triggerid';
-			$sqlParts['where'][] = dbConditionString('f.function', $options['functions']);
+			$sqlParts['where'][] = dbConditionString('f.name', $options['functions']);
 		}
 
 		// monitored
@@ -344,7 +339,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 			$sqlParts['from']['functions'] = 'functions f';
 			$sqlParts['from']['items'] = 'items i';
 			$sqlParts['from']['hosts_groups'] = 'hosts_groups hg';
-			$sqlParts['from']['groups'] = 'groups g';
+			$sqlParts['from']['hstgrp'] = 'hstgrp g';
 			$sqlParts['where']['ft'] = 'f.triggerid=t.triggerid';
 			$sqlParts['where']['fi'] = 'f.itemid=i.itemid';
 			$sqlParts['where']['hgi'] = 'hg.hostid=i.hostid';
@@ -378,8 +373,8 @@ class CTriggerPrototype extends CTriggerGeneral {
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$dbRes = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($triggerPrototype = DBfetch($dbRes)) {
-			if ($options['countOutput'] !== null) {
-				if ($options['groupCount'] !== null) {
+			if ($options['countOutput']) {
+				if ($options['groupCount']) {
 					$result[] = $triggerPrototype;
 				}
 				else {
@@ -391,7 +386,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 			}
 		}
 
-		if ($options['countOutput'] !== null) {
+		if ($options['countOutput']) {
 			return $result;
 		}
 
@@ -417,7 +412,7 @@ class CTriggerPrototype extends CTriggerGeneral {
 		}
 
 		// removing keys (hash -> array)
-		if ($options['preservekeys'] === null) {
+		if (!$options['preservekeys']) {
 			$result = zbx_cleanHashes($result);
 		}
 
@@ -427,8 +422,6 @@ class CTriggerPrototype extends CTriggerGeneral {
 	/**
 	 * Create new trigger prototypes.
 	 *
-	 * @see https://www.zabbix.com/documentation/3.2/manual/api/reference/triggerprototype/create
-	 *
 	 * @param array $trigger_prototypes
 	 *
 	 * @return array
@@ -463,8 +456,6 @@ class CTriggerPrototype extends CTriggerGeneral {
 	/**
 	 * Update existing trigger prototypes.
 	 *
-	 * @see https://www.zabbix.com/documentation/3.2/manual/api/reference/triggerprototype/update
-	 *
 	 * @param array $trigger_prototypes
 	 *
 	 * @return array
@@ -499,92 +490,60 @@ class CTriggerPrototype extends CTriggerGeneral {
 	/**
 	 * Delete existing trigger prototypes.
 	 *
-	 * @see https://www.zabbix.com/documentation/3.2/manual/api/reference/triggerprototype/delete
-	 *
-	 * @param array $triggerPrototypeIds
-	 * @param bool  $nopermissions
+	 * @param array $triggerids
 	 *
 	 * @throws APIException
 	 *
 	 * @return array
 	 */
-	public function delete(array $triggerPrototypeIds, $nopermissions = false) {
-		if (!$triggerPrototypeIds) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+	public function delete(array $triggerids) {
+		$this->validateDelete($triggerids, $db_triggers);
+
+		CTriggerPrototypeManager::delete($triggerids);
+
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_TRIGGER_PROTOTYPE, $db_triggers);
+
+		return ['triggerids' => $triggerids];
+	}
+
+	/**
+	 * Validates the input parameters for the delete() method.
+	 *
+	 * @param array $triggerids   [IN/OUT]
+	 * @param array $db_triggers  [OUT]
+	 *
+	 * @throws APIException if the input is invalid.
+	 */
+	protected function validateDelete(array &$triggerids, array &$db_triggers = null) {
+		$api_input_rules = ['type' => API_IDS, 'flags' => API_NOT_EMPTY, 'uniq' => true];
+		if (!CApiInputValidator::validate($api_input_rules, $triggerids, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		// TODO: remove $nopermissions hack
-		if (!$nopermissions) {
-			$dbTriggerPrototypes = $this->get([
-				'triggerids' => $triggerPrototypeIds,
-				'output' => ['description', 'expression', 'templateid'],
-				'editable' => true,
-				'preservekeys' => true
-			]);
-
-			foreach ($triggerPrototypeIds as $triggerPrototypeId) {
-				if (!isset($dbTriggerPrototypes[$triggerPrototypeId])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS, _(
-						'No permissions to referred object or it does not exist!'
-					));
-				}
-				$dbTriggerPrototype = $dbTriggerPrototypes[$triggerPrototypeId];
-
-				if ($dbTriggerPrototype['templateid'] != 0) {
-					self::exception(ZBX_API_ERROR_PARAMETERS, _s('Cannot delete templated trigger "%1$s:%2$s".',
-						$dbTriggerPrototype['description'],
-						CMacrosResolverHelper::resolveTriggerExpression($dbTriggerPrototype['expression'])
-					));
-				}
-			}
-		}
-
-		// get child trigger prototypes
-		$parentTriggerPrototypeIds = $triggerPrototypeIds;
-		do {
-			$dbTriggerPrototypes = DBselect(
-				'SELECT triggerid'.
-				' FROM triggers'.
-				' WHERE '.dbConditionInt('templateid', $parentTriggerPrototypeIds)
-			);
-			$parentTriggerPrototypeIds = [];
-			while ($dbTriggerPrototype = DBfetch($dbTriggerPrototypes)) {
-				$parentTriggerPrototypeIds[] = $dbTriggerPrototype['triggerid'];
-				$triggerPrototypeIds[$dbTriggerPrototype['triggerid']] = $dbTriggerPrototype['triggerid'];
-			}
-		} while ($parentTriggerPrototypeIds);
-
-		// delete triggers created from this prototype
-		$createdTriggerIds = DBfetchColumn(DBselect(
-			'SELECT triggerid'.
-			' FROM trigger_discovery'.
-			' WHERE '.dbConditionInt('parent_triggerid', $triggerPrototypeIds)
-		), 'triggerid');
-		if ($createdTriggerIds) {
-			API::Trigger()->delete($createdTriggerIds, true);
-		}
-
-		// select all trigger prototypes which are deleted (include children)
-		$dbTriggerPrototypes = $this->get([
-			'triggerids' => $triggerPrototypeIds,
-			'output' => ['triggerid', 'description', 'expression'],
-			'nopermissions' => true,
-			'preservekeys' => true,
-			'selectHosts' => ['name']
+		$db_triggers = $this->get([
+			'output' => ['triggerid', 'description', 'expression', 'templateid'],
+			'triggerids' => $triggerids,
+			'editable' => true,
+			'preservekeys' => true
 		]);
 
-		// TODO: REMOVE info
-		foreach ($dbTriggerPrototypes as $dbTriggerPrototype) {
-			info(_s('Deleted: Trigger prototype "%1$s" on "%2$s".', $dbTriggerPrototype['description'],
-					implode(', ', zbx_objectValues($dbTriggerPrototype['hosts'], 'name'))));
+		foreach ($triggerids as $triggerid) {
+			if (!array_key_exists($triggerid, $db_triggers)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
 
-			add_audit_ext(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_TRIGGER_PROTOTYPE, $dbTriggerPrototype['triggerid'],
-					$dbTriggerPrototype['description'].':'.$dbTriggerPrototype['expression'], null, null, null);
+			$db_trigger = $db_triggers[$triggerid];
+
+			if ($db_trigger['templateid'] != 0) {
+				self::exception(ZBX_API_ERROR_PARAMETERS,
+					_s('Cannot delete templated trigger prototype "%1$s:%2$s".', $db_trigger['description'],
+						CMacrosResolverHelper::resolveTriggerExpression($db_trigger['expression'])
+					)
+				);
+			}
 		}
-
-		DB::delete('triggers', ['triggerid' => $triggerPrototypeIds]);
-
-		return ['triggerids' => $triggerPrototypeIds];
 	}
 
 	/**
