@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -59,7 +59,10 @@ $availableJScripts = [
 	'servercheck.js' => '',
 	'flickerfreescreen.js' => '',
 	'multiselect.js' => '',
+	'colorpicker.js' => '',
 	'chkbxrange.js' => '',
+	'csvggraphwidget.js' => '',
+	'layout.mode.js' => '',
 	// vendors
 	'prototype.js' => 'vendors/',
 	'jquery.js' => 'vendors/',
@@ -67,42 +70,37 @@ $availableJScripts = [
 	// classes
 	'class.bbcode.js' => '',
 	'class.calendar.js' => '',
+	'class.cclock.js' => '',
 	'class.cdate.js' => '',
 	'class.cdebug.js' => '',
 	'class.cmap.js' => '',
 	'class.cmessages.js' => '',
+	'class.cnavtree.js' => '',
 	'class.cookie.js' => '',
+	'class.coverride.js' => '',
+	'class.crangecontrol.js' => '',
 	'class.cscreen.js' => '',
 	'class.csuggest.js' => '',
-	'class.cswitcher.js' => '',
+	'class.csvggraph.js' => '',
 	'class.ctree.js' => '',
 	'class.curl.js' => '',
-	'class.rpc.js' => '',
+	'class.cverticalaccordion.js' => '',
+	'class.mapWidget.js' => '',
 	'class.svg.canvas.js' => 'vector/',
 	'class.svg.map.js' => 'vector/',
-	'class.pmaster.js' => '',
 	'class.cviewswitcher.js' => '',
+	'class.pmaster.js' => '',
+	'class.rpc.js' => '',
 	'init.js' => '',
 	// templates
 	'sysmap.tpl.js' => 'templates/',
 	// page-specific scripts
 	'items.js' => 'pages/',
-	'tr_logform.js' => 'pages/',
 ];
 
 $tranStrings = [
 	'gtlc.js' => [
-		'S_ALL_S' => _('All'),
-		'S_ZOOM' => _('Zoom'),
-		'S_FIXED_SMALL' => _('fixed'),
-		'S_DYNAMIC_SMALL' => _('dynamic'),
-		'S_NOW_SMALL' => _('now'),
-		'S_YEAR_SHORT' => _x('y', 'year short'),
-		'S_MONTH_SHORT' => _x('m', 'month short'),
-		'S_DAY_SHORT' => _x('d', 'day short'),
-		'S_HOUR_SHORT' => _x('h', 'hour short'),
-		'S_MINUTE_SHORT' => _x('m', 'minute short'),
-		'S_DATE_FORMAT' => DATE_TIME_FORMAT
+		'S_MINUTE_SHORT' => _x('m', 'minute short')
 	],
 	'dashboard.grid.js' => [
 		'Edit widget' => _('Edit widget'),
@@ -114,17 +112,24 @@ $tranStrings = [
 		'Delete' => _('Delete'),
 		'You have unsaved changes.' => _('You have unsaved changes.'),
 		'Are you sure, you want to leave this page?' => _('Are you sure, you want to leave this page?'),
-		'Add a new widget' => _('Add a new widget')
+		'Cannot add widgets in kiosk mode' => _('Cannot add widgets in kiosk mode'),
+		'Add a new widget' => _('Add a new widget'),
+		'Adjust widget refresh interval' => _('Adjust widget refresh interval')
 	],
 	'functions.js' => [
 		'Cancel' => _('Cancel'),
+		'S_CLOSE' => _('Close'),
 		'Execute' => _('Execute'),
-		'Execution confirmation' => _('Execution confirmation')
-	],
-	'tr_logform.js' => [
-		'S_REMOVE' => _('Remove')
+		'Execution confirmation' => _('Execution confirmation'),
+		'S_YEAR_SHORT' => _x('y', 'year short'),
+		'S_MONTH_SHORT' => _x('m', 'month short'),
+		'S_DAY_SHORT' => _x('d', 'day short'),
+		'S_HOUR_SHORT' => _x('h', 'hour short'),
+		'S_MINUTE_SHORT' => _x('m', 'minute short'),
+		'Do you wish to replace the conditional expression?' => _('Do you wish to replace the conditional expression?')
 	],
 	'class.calendar.js' => [
+		'S_CALENDAR' => _('Calendar'),
 		'S_JANUARY' => _('January'),
 		'S_FEBRUARY' => _('February'),
 		'S_MARCH' => _('March'),
@@ -137,16 +142,20 @@ $tranStrings = [
 		'S_OCTOBER' => _('October'),
 		'S_NOVEMBER' => _('November'),
 		'S_DECEMBER' => _('December'),
+		'S_MONDAY' => _('Monday'),
+		'S_TUESDAY' => _('Tuesday'),
+		'S_WEDNESDAY' => _('Wednesday'),
+		'S_THURSDAY' => _('Thursday'),
+		'S_FRIDAY' => _('Friday'),
+		'S_SATURDAY' => _('Saturday'),
+		'S_SUNDAY' => _('Sunday'),
 		'S_MONDAY_SHORT_BIG' => _x('M', 'Monday short'),
 		'S_TUESDAY_SHORT_BIG' => _x('T', 'Tuesday short'),
 		'S_WEDNESDAY_SHORT_BIG' => _x('W', 'Wednesday short'),
 		'S_THURSDAY_SHORT_BIG' => _x('T', 'Thursday short'),
 		'S_FRIDAY_SHORT_BIG' => _x('F', 'Friday short'),
 		'S_SATURDAY_SHORT_BIG' => _x('S', 'Saturday short'),
-		'S_SUNDAY_SHORT_BIG' => _x('S', 'Sunday short'),
-		'S_NOW' => _('Now'),
-		'S_DONE' => _('Done'),
-		'S_TIME' => _('Time')
+		'S_SUNDAY_SHORT_BIG' => _x('S', 'Sunday short')
 	],
 	'class.cmap.js' => [
 		'S_ON' => _('On'),
@@ -160,8 +169,7 @@ $tranStrings = [
 		'S_IMAGE' => _('Image'),
 		'S_DEFAULT' => _('Default'),
 		'S_PLEASE_SELECT_TWO_ELEMENTS' => _('Please select two elements'),
-		'S_DOT' => _('Dot'),
-		'S_TWO_ELEMENTS_SHOULD_BE_SELECTED' => _('Two elements should be selected'),
+		'S_TWO_MAP_ELEMENTS_SHOULD_BE_SELECTED' => _('Two map elements should be selected'),
 		'S_DELETE_SELECTED_ELEMENTS_Q' => _('Delete selected elements?'),
 		'S_DELETE_SELECTED_SHAPES_Q' => _('Delete selected shapes?'),
 		'S_BRING_TO_FRONT' => _('Bring to front'),
@@ -178,37 +186,51 @@ $tranStrings = [
 		'S_DELETE_LINKS_BETWEEN_SELECTED_ELEMENTS_Q' => _('Delete links between selected elements?'),
 		'S_MACRO_EXPAND_ERROR' => _('Cannot expand macros.'),
 		'S_NO_IMAGES' => 'You need to have at least one image uploaded to create map element. Images can be uploaded in Administration->General->Images section.',
-		'Colour "%1$s" is not correct: expecting hexadecimal colour code (6 symbols).' => _('Colour "%1$s" is not correct: expecting hexadecimal colour code (6 symbols).')
+		'S_COLOR_IS_NOT_CORRECT' => _('Colour "%1$s" is not correct: expecting hexadecimal colour code (6 symbols).')
 	],
 	'class.cmessages.js' => [
 		'S_MUTE' => _('Mute'),
 		'S_UNMUTE' => _('Unmute'),
-		'S_MESSAGES' => _('Messages'),
 		'S_CLEAR' => _('Clear'),
 		'S_SNOOZE' => _('Snooze')
 	],
 	'class.cookie.js' => [
 		'S_MAX_COOKIE_SIZE_REACHED' => _('We are sorry, the maximum possible number of elements to remember has been reached.')
 	],
+	'class.coverride.js' => [
+		'S_COLOR' => _('colour'),
+		'S_TIME_SHIFT' => _('time shift')
+	],
+	'class.cverticalaccordion.js' => [
+		'S_COLLAPSE' => _('Collapse'),
+		'S_EXPAND' => _('Expand')
+	],
 	'main.js' => [
 		'S_EXPAND' => _('Expand'),
 		'S_COLLAPSE' => _('Collapse'),
+		'S_CLOSE' => _('Close')
 	],
 	'multiselect.js' => [
 		'No matches found' => _('No matches found'),
 		'More matches found...' => _('More matches found...'),
 		'type here to search' => _('type here to search'),
 		'new' => _('new'),
-		'Select' => _('Select')
+		'Select' => _('Select'),
+		'Added, %1$s' => _x('Added, %1$s', 'screen reader'),
+		'Removed, %1$s' => _x('Removed, %1$s', 'screen reader'),
+		'%1$s, read only' => _x('%1$s, read only', 'screen reader'),
+		'Can not be removed' => _x('Can not be removed', 'screen reader'),
+		'Selected, %1$s in position %2$d of %3$d' => _x('Selected, %1$s in position %2$d of %3$d', 'screen reader'),
+		'Selected, %1$s, read only, in position %2$d of %3$d' => _x('Selected, %1$s, read only, in position %2$d of %3$d', 'screen reader'),
+		'More than %1$d matches for %2$s found' => _x('More than %1$d matches for %2$s found', 'screen reader'),
+		'%1$d matches for %2$s found' => _x('%1$d matches for %2$s found', 'screen reader'),
+		'%1$s preselected, use down,up arrow keys and enter to select' => _x('%1$s preselected, use down,up arrow keys and enter to select', 'screen reader')
 	],
 	'menupopup.js' => [
 		'Acknowledge' => _('Acknowledge'),
-		'Access denied' => _('Access denied'),
-		'Cancel' => _('Cancel'),
 		'Configuration' => _('Configuration'),
 		'Create trigger' => _('Create trigger'),
-		'Dashboard sharing' => _('Dashboard sharing'),
-		'Delete service "%1$s"?' => _('Delete service "%1$s"?'),
+		'Description' => _('Description'),
 		'Do you wish to replace the conditional expression?' => _('Do you wish to replace the conditional expression?'),
 		'Edit trigger' => _('Edit trigger'),
 		'Insert expression' => _('Insert expression'),
@@ -229,21 +251,18 @@ $tranStrings = [
 		'Refresh interval' => _('Refresh interval'),
 		'Refresh interval multiplier' => _('Refresh interval multiplier'),
 		'Scripts' => _('Scripts'),
-		'Something went wrong. Please try again later!' => _('Something went wrong. Please try again later!'),
 		'Submap' => _('Submap'),
-		'Trigger' => _('Trigger'),
-		'Triggers' => _('Triggers'),
-		'Update' => _('Update'),
+		'S_TRIGGER' => _('Trigger'),
 		'URL' => _('URL'),
 		'URLs' => _('URLs'),
 		'No refresh' => _('No refresh'),
-		'You need permission to perform this action!' => _('You need permission to perform this action!'),
 		'10 seconds' => _n('%1$s second', '%1$s seconds', 10),
 		'30 seconds' => _n('%1$s second', '%1$s seconds', 30),
 		'1 minute' => _n('%1$s minute', '%1$s minutes', 1),
 		'2 minutes' => _n('%1$s minute', '%1$s minutes', 2),
 		'10 minutes' => _n('%1$s minute', '%1$s minutes', 10),
-		'15 minutes' => _n('%1$s minute', '%1$s minutes', 15)
+		'15 minutes' => _n('%1$s minute', '%1$s minutes', 15),
+		'S_SELECTED_SR' => _x('%1$s, selected', 'screen reader')
 	],
 	'items.js' => [
 		'To set a host interface select a single item type for all items' => _('To set a host interface select a single item type for all items'),
@@ -259,6 +278,16 @@ $tranStrings = [
 		'Cancel' => _('Cancel'),
 		'Add child element' => _('Add child element'),
 		'Add multiple maps' => _('Add multiple maps')
+	],
+	'colorpicker.js' => [
+		'S_CLOSE' => _('Close')
+	],
+	'class.csvggraph.js' => [
+		'S_DISPLAYING_FOUND' => _('Displaying %1$s of %2$s found'),
+		'S_MINUTE_SHORT' => _x('m', 'minute short')
+	],
+	'common.js' => [
+		'Cancel' => _('Cancel')
 	]
 ];
 
